# Roseau Load Flow

![CI](https://github.com/RoseauTechnologies/Roseau_Load_Flow/workflows/CI/badge.svg)
![pre-commit](https://github.com/RoseauTechnologies/Roseau_Load_Flow/actions/workflows/pre-commit.yml/badge.svg)

_Roseau Load Flow_ is a highly capable three-phase load flow solver with an ergonomic Python API
for unbalanced power flow analysis.

This project is compatible with Python version 3.10 and newer. The
[installation instructions](https://roseau-load-flow.roseautechnologies.com/Installation.html)
will guide you through the installation process. If you are new to _Roseau Load Flow_, we recommend you start with the
[getting started tutorial](https://roseau-load-flow.roseautechnologies.com/usage/Getting_Started.html).
You can find the complete documentation at https://roseau-load-flow.roseautechnologies.com/.

> [!IMPORTANT]
> Starting with version 0.7.0, Roseau Load Flow is no longer supplied as a SaaS. The software is now
> available as a standalone Python library.

## License

The project is _partially_ open source but using the solver requires a license. The license key
`A8C6DA-9405FB-E74FB9-C71C3C-207661-V3` can be used free of charge with networks containing up to 10
buses. To obtain a personal or commercial license, please contact us
at [contact@roseautechnologies.com](mailto:contact@roseautechnologies.com).

> [!NOTE]
> Licenses are given free of charge for **students and teachers**. Please contact us at
> contact@roseautechnologies.com for more information.

Read more at [License](https://roseau-load-flow.roseautechnologies.com/License.html).

## Network data

With this library, there is a sample of 20 low-voltage and 20 medium-voltage feeders included for an easy
start! Each network is given with its summer and winter load point. At _Roseau Technologies_, we are able to provide
the major part of the French medium and low voltage networks. For more information, please contact us at
contact@roseautechnologies.com.

![Catalogue of networks](https://github.com/RoseauTechnologies/Roseau_Load_Flow/blob/main/doc/_static/Network/Catalogue.png?raw=True)

## Bug reports / Feature requests

If you find a bug or have a feature request, please open an issue on
[GitHub](https://github.com/RoseauTechnologies/Roseau_Load_Flow/issues)

## Credits

This software is developed by [Roseau Technologies](https://www.roseautechnologies.com/en).
[![Linkedin](https://i.stack.imgur.com/gVE0j.png) LinkedIn](https://www.linkedin.com/company/roseau-technologies/)
&nbsp;
[![GitHub](https://i.stack.imgur.com/tskMh.png) GitHub](https://github.com/RoseauTechnologies)
